package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````@"````````!``````````&BQ````
M`````````$``.``)`$``'``;``8````%````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````,"=````````P)T`````````
M`"````````$````&````8*L```````!@JR```````&"K(```````P`0`````
M``!(%0``````````(````````@````8```"(JP```````(BK(```````B*L@
M``````!``@```````$`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````X)8```````#@E@```````."6````````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````&"K````````8*L@``````!@JR``
M`````*`$````````H`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````(````&````(`````0`
M```4`````P```$=.50`>,."#0WX$!OBO8946/]LN)_V/ZQ$```!$````!```
M``@````@'!``!4`$AB@"0`"0A@"`@BD`($D@!`FXHAA-N@0&"@````!$````
M2````$P```!-````5````%4```!7````6P```%P`````````7@```&$```!B
M````8P``````````````;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.N(WQ#M5D
MU'S9<5@<XD?&`:Q+X\#RV],=NN.2?,+E/RSZH6Q@LP&+;VL)0]9FK\QFQ;F<
M0$)%U>S$B060B`=PTSGRBQP-%.*>VLWCGC-BV^T,.I<+5J2;EJ?=HVM_J9R;
MX:<""@J*$%>CX/M)````````````````````````````````$0$``!(`````
M````````````````````_`$``!(`````````````````````````>P(``!(`
M````````````````````````4`(``!(`````````````````````````$0``
M`"``````````````````````````@@(``!(`````````````````````````
M!P,``!(`````````````````````````M````!(`````````````````````
M````EP(``!(`````````````````````````@P$``!(`````````````````
M````````[P(``!(`````````````````````````YP(``!(`````````````
M````````````A````!(`````````````````````````U@,``!(`````````
M````````````````#`$``!(`````````````````````````LP(``!(`````
M````````````````````I0(``!(`````````````````````````:@(``!(`
M``````````````````````````,``!(`````````````````````````'0,`
M`!(`````````````````````````9P$``!(`````````````````````````
M-0$``!(`````````````````````````P@```!(`````````````````````
M````L0$``!(`````````````````````````*0(``!(`````````````````
M````````80(``!(`````````````````````````.0(``!(`````````````
M````````````6`(``!(`````````````````````````G@$``!(`````````
M````````````````D`(``!(`````````````````````````]P$``!(`````
M````````````````````80,``!(`````````````````````````6@,``!(`
M````````````````````````0P$``!(`````````````````````````$`,`
M`!(`````````````````````````+0```"``````````````````````````
MQP(``!(`````````````````````````9````!(`````````````````````
M````%0(``!(`````````````````````````J@$``!(`````````````````
M````````DP```!(`````````````````````````GP```!(`````````````
M````````````7`$``!(`````````````````````````(@$``!(`````````
M````````````````5@```!(`````````````````````````%@$``!(`````
M````````````````````S@(``!(`````````````````````````DP$``!(`
M````````````````````````\````!(`````````````````````````B`(`
M`!(`````````````````````````\`$``!(`````````````````````````
M2P,``!(`````````````````````````)`,``!(`````````````````````
M````=0$``!(`````````````````````````<P```!(`````````````````
M````````4P,``!(`````````````````````````G@(``!(`````````````
M````````````U````!(`````````````````````````4P$``!(`````````
M````````````````W`(``!(`````````````````````````2P(``!(`````
M````````````````````#0(``!(`````````````````````````N0(``!(`
M````````````````````````/````"``````````````````````````+@,`
M`"(`````````````````````````K`(``!(`````````````````````````
M/0,``!(`````````````````````````WP,``!(`#@"`5@```````'``````
M````K0,``!(`#P"$5P``````````````````!`0``!(`#@!@1@```````"0,
M````````;@,``!(`#@!0'@```````"T"````````LP,``!(`#@"0/P``````
M``4`````````<@0``!(`#@"@/P```````!H"````````;`0``!(`"P!@&@``
M````````````````GP0``!(`#@"04@```````.T#````````D@,``!``&0`@
ML"``````````````````ZP,``!(`#@#`00```````"H`````````'@0``!$`
M$`"05P````````0`````````O`$``!$`%0!PJR```````!,`````````G@,`
M`!``&0"HP"``````````````````:@0``!(`#@!`/@```````#``````````
M?P0``!(`#@"`10```````-P`````````D00``!(`#@#01````````'0`````
M````$00``!``&```L"``````````````````^`,``!(`#@#P00```````/$`
M````````<P,``!$`&0!(L"````````@`````````BP,``!``&``@L"``````
M````````````=`,``"$`&0!(L"````````@`````````4P0``!$`&``8L"``
M``````@`````````^0(``!$`&0!@L"````````@`````````HP,``!(`#@"`
M5P````````(`````````0P0``!(`#@`05P```````&4`````````%P0``!(`
M#@"`(````````"L`````````$P0``"``&```L"```````````````````0$`
M`!$`&0`@L"````````0`````````=0,``"$`&0!(L"````````@`````````
MQ`,``!(`#@!010```````"0`````````+00``!(`#@#`/@```````,$`````
M````XP```!$`&0!`L"````````$`````````700``!(`#@#P0@```````-L!
M`````````&QI8G!E<FPN<V\N-2XR-@!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO
M8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V
M7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?
M:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`
M4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A
M9"YS;RXP`&]P96XV-`!R96%D`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!P
M=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&QI8F,N<V\N-@!?7W)E9VES=&5R
M7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C
M:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED
M`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M
M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V
M-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?;65M8W!Y7V-H:P!S=')C:'(`
M<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M;6]V
M90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!L
M:6)C<GEP="YS;RXQ`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`%]?;&EB8U]C
M<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E
M='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P
M87)?;6MT;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C
M=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A
M<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB
M<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"
M0U\R+C(N-0!'3$E"0U\R+C$T`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,
M24)#7S(N-`````(``P`"``(````"``(````"`````@`"`````@````(``@`$
M``(``@````````````,``@`%``(````"``,``@`"````!@````<````#``(`
M````````````````!@```````@`#``(``@```````@`"```````"``(``P`&
M`````@`"``8``0`!``$``0`!``$``0`!``$``0`!`````0`!``$``0`!``$`
M`@`!``(``0`"``$``0`!``$````"``$``0````$``0`!`.`!```0````(```
M`'4::0D```,`M00````````!``4`+P(``!``````````E)&6!@``!P#!!```
M$````'09:0D```8`S`0``!````!R&6D)```%`-@$```0````%&EI#0``!`#D
M!```$````'4::0D```(`M00```````!@JR````````@`````````@"$`````
M``!HJR````````@`````````0"$````````(L"````````@`````````"+`@
M```````8L"````````@`````````J%H```````"XKR````````8````%````
M``````````#`KR````````8````*``````````````#(KR````````8````@
M``````````````#0KR````````8````D``````````````#8KR````````8`
M```L``````````````#@KR````````8````W``````````````#HKR``````
M``8```!```````````````#PKR````````8```!!``````````````!PJR``
M``````4```!/```````````````@L"````````4```!?``````````````!`
ML"````````4```!C``````````````!(L"````````4```!6````````````
M``!@L"````````4```!:``````````````#@K2````````<````!````````
M``````#HK2````````<````"``````````````#PK2````````<````#````
M``````````#XK2````````<````$````````````````KB````````<````&
M```````````````(KB````````<````'```````````````0KB````````<`
M```(```````````````8KB````````<````)```````````````@KB``````
M``<````+```````````````HKB````````<````,```````````````PKB``
M``````<````-```````````````XKB````````<````.``````````````!`
MKB````````<````/``````````````!(KB````````<````0````````````
M``!0KB````````<````1``````````````!8KB````````<````2````````
M``````!@KB````````<````3``````````````!HKB````````<````4````
M``````````!PKB````````<````5``````````````!XKB````````<````6
M``````````````"`KB````````<````7``````````````"(KB````````<`
M```8``````````````"0KB````````<````9``````````````"8KB``````
M``<````:``````````````"@KB````````<````;``````````````"HKB``
M``````<````<``````````````"PKB````````<````=``````````````"X
MKB````````<````>``````````````#`KB````````<````?````````````
M``#(KB````````<````A``````````````#0KB````````<````B````````
M``````#8KB````````<````C``````````````#@KB````````<````E````
M``````````#HKB````````<````F``````````````#PKB````````<````G
M``````````````#XKB````````<````H````````````````KR````````<`
M```I```````````````(KR````````<````J```````````````0KR``````
M``<````K```````````````8KR````````<````M```````````````@KR``
M``````<````N```````````````HKR````````<````O```````````````P
MKR````````<````P```````````````XKR````````<````Q````````````
M``!`KR````````<````R``````````````!(KR````````<````S````````
M``````!0KR````````<````T``````````````!8KR````````<````U````
M``````````!@KR````````<````V``````````````!HKR````````<````X
M``````````````!PKR````````<````Y``````````````!XKR````````<`
M```Z``````````````"`KR````````<````[``````````````"(KR``````
M``<````\``````````````"0KR````````<````]``````````````"8KR``
M``````<````^``````````````"@KR````````<````_``````````````"H
MKR````````<```!"``````````````"PKR````````<```!#````````````
M``!(@^P(2(L%994@`$B%P'0"_]!(@\0(PP```````````/\U2I,@`/\E3),@
M``\?0`#_)4J3(`!H`````.G@_____R5"DR``:`$```#IT/____\E.I,@`&@"
M````Z<#_____)3*3(`!H`P```.FP_____R4JDR``:`0```#IH/____\E(I,@
M`&@%````Z9#_____)1J3(`!H!@```.F`_____R42DR``:`<```#I</____\E
M"I,@`&@(````Z6#_____)0*3(`!H"0```.E0_____R7ZDB``:`H```#I0/__
M__\E\I(@`&@+````Z3#_____)>J2(`!H#````.D@_____R7BDB``:`T```#I
M$/____\EVI(@`&@.````Z0#_____)=*2(`!H#P```.GP_O___R7*DB``:!``
M``#IX/[___\EPI(@`&@1````Z=#^____);J2(`!H$@```.G`_O___R6RDB``
M:!,```#IL/[___\EJI(@`&@4````Z:#^____):*2(`!H%0```.F0_O___R6:
MDB``:!8```#I@/[___\EDI(@`&@7````Z7#^____)8J2(`!H&````.E@_O__
M_R6"DB``:!D```#I4/[___\E>I(@`&@:````Z4#^____)7*2(`!H&P```.DP
M_O___R5JDB``:!P```#I(/[___\E8I(@`&@=````Z1#^____)5J2(`!H'@``
M`.D`_O___R52DB``:!\```#I\/W___\E2I(@`&@@````Z>#]____)4*2(`!H
M(0```.G0_?___R4ZDB``:"(```#IP/W___\E,I(@`&@C````Z;#]____)2J2
M(`!H)````.F@_?___R4BDB``:"4```#ID/W___\E&I(@`&@F````Z8#]____
M)1*2(`!H)P```.EP_?___R4*DB``:"@```#I8/W___\E`I(@`&@I````Z5#]
M____)?J1(`!H*@```.E`_?___R7RD2``:"L```#I,/W___\EZI$@`&@L````
MZ2#]____)>*1(`!H+0```.D0_?___R7:D2``:"X```#I`/W___\ETI$@`&@O
M````Z?#\____)<J1(`!H,````.G@_/___R7"D2``:#$```#IT/S___\ENI$@
M`&@R````Z<#\____);*1(`!H,P```.FP_/___R6JD2``:#0```#IH/S___\E
MHI$@`&@U````Z9#\____)9J1(`!H-@```.F`_/___R62D2``:#<```#I</S_
M__\EBI$@`&@X````Z6#\____)8*1(`!H.0```.E0_/___R5ZD2``:#H```#I
M0/S___\EJI$@`&:0``````````!54TB#[#B)?"0<2(ET)!!(C7PD'$B)5"0(
M2(UT)!!(C50D"&1(BP0E*````$B)1"0H,<#H&/[__TB+-4F1(`!(BSU*D2``
M2(GRZ%(X``"`/9N1(```=2_H-/W__TB%P$B)!>JA(``/A+<!``!(B<?H;/S_
M_XL]5I$@`.CA_?__QH#1"````(L]1)$@`.C/_?__@(BJ!````HL],I$@`.B]
M_?__@(BJ!````8M$)!R->`5(N/________\?2&/_2#G'#X<B`0``2,'G`TB-
M'3\Z``#H"?W__TB+?"002(D%5:$@`,<%4Z$@``0```!(BQ=(B5@(2(T=&3H`
M`$B)6!A(B1!(BQ6_D"``2(E0$(M4)!R#^@%$C4H$?BU$C4H$2(/'"+X%````
M9@\?A```````3(L'2&/.@\8!2(/'"$$Y\4R)1,CX=>E(BST"H2``36/)2(TU
MR!X``(/"`T4QP$K'1,CX`````$B)P>AQ_?__A<")PW1D2(L]U*`@`$B-;"0D
MZ-K[__](C3U6.```,<!(B>[HN1<``$B%P'0J2(L]K:`@`.A8^___Z`/]__^)
MV$B+7"0H9$@S'"4H````=5](@\0X6UW#2(L]>Z`@`$B%_W0LZ%DV``#KPTB+
M/7"@(`#HF_W__XG#ZXQ(C34PBR``2(T]G#<``#'`Z)+\__](C3V3-P``2(GN
MZ$,7``!(A<!(B<=(B04NH"``=(#KM.@-^___OP$```#H<_W__P\?`#'M28G1
M7DB)XDB#Y/!05$R-!>HV``!(C0US-@``2(T]K/W___\5'H\@`/0/'T0``$B-
M/6F/(`!52(T%88\@`$@Y^$B)Y7092(L%ZHX@`$B%P'0-7?_@9BX/'X0`````
M`%W##Q]``&8N#Q^$``````!(C3TICR``2(TU(H\@`%5(*?Y(B>5(P?X#2(GP
M2,'H/T@!QDC1_G082(L%R8X@`$B%P'0,7?_@9@\?A```````7<,/'T``9BX/
M'X0``````(`](8\@``!U+TB#/9^.(```54B)Y70,2(L]JHX@`.C=_/__Z$C_
M___&!?F.(``!7<,/'X``````\\-F#Q]$``!52(GE7>EF____9@\?1```05=!
M5DR-3SA!54%413'`55-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)X6:0
M0XL$`4N+-`$/R$B)\HG`2,'J($J)!$%(B?!(P>XX2,'H*"4`_P``2`GP2(G6
M2,'B"$C!YAB!X@``_P")]D@)\$@)T$J)1$$(28/`"$F#^$!UKDB-L0`"```/
M'X``````2(M!:$@S04!(@\$(2#-!"$@S0?A(C10`2,'H'T@)T(/@_TB)07A(
M.?%UU4R+%TB+7Q!(BW<@2(MO&$R+3PA,B=!,B=)(P>H;2,'@!4@)T`,$)(V4
M,)EY@EI(B=A(BW0D"$@QZ$PAR$@QZ$B-M#69>8):1(TL`DR)RDR)R$C!Z`)(
MP>(>2`G"2(G838GHB=%)P>@;2#'(3"'02#'82`'P3(GN2,'F!4P)QD2-)`9,
MB=9,B=!(P>8>2,'H`D@)\$B+="0038GC2#'"2<'K&T&)P$PAZDB-M#.9>8):
M2#'*2`'R3(GF2,'F!4P)WD2-'!9,B>Y(BU0D&$G![0)(P>8>3`GN2#'P2(V4
M$9EY@EI,B=E,(>!!B?9,,<!(P>D;2`'03(G:2,'B!4@)RDR)X4G![`)$C2P"
M2,'A'DB+5"0@3`GA2(GP2#'(3(GN08G,3"'828V4$)EY@EI(P>X;3#'P2`'0
M3(GJ2,'B!4@)\D2-!`),B=I(BT0D*$G!ZP)(P>(>3`G:3(G&2#'128V$!IEY
M@EI(P>X;3"'I08G33#'A2`'!3(G`2,'@!4@)\$2--`A,B>A(BTPD,$G![0)(
MP>`>3`GH3(GV2#'"28V,#)EY@EI!B<5,(<),,=I(`<I,B?%(P>$%2,'N&T@)
M\4R)QDG!Z`)$C2012,'F'DB+5"0X3`G&2#'P3(GA08GP3"'P28V4$YEY@EI(
MP>D;3#'H2`'03(GB2,'B!4@)RDR)\4G![@)$C1P"2,'A'DB+5"1`3`GQ2(GP
M2#'(3(G>08G.3"'@28V4%9EY@EI(P>X;3#'`2`'03(G:2,'B!4@)\D2-+`),
MB>)(BT0D2$G![`)(P>(>3`GB3(GN2#'128V$`)EY@EI(P>X;3"'908G43#'Q
M2`'!3(GH2,'@!4@)\$2-!`A,B=A(BTPD4$G!ZP)(P>`>3`G83(G&2#'"28V,
M#IEY@EI(P>X;3"'J08G#3#'B2`'*3(G!2,'A!4@)\4R)[DG![0)$C3012,'F
M'DB+5"183`GN2#'P3(GQ08GU3"'`28V4%)EY@EI(P>D;3#'82`'03(GR2,'B
M!4@)RDR)P4G!Z`)$C20"2,'A'DB+5"1@3`G!2(GP2#'(3(GF08G(28V4$YEY
M@EI,(?!(P>X;3#'H2`'03(GB2,'B!4@)\D2-'`),B?)(BT0D:$C!XAY)P>X"
M3`GR3(G>2#'128V$!9EY@EI(P>X;3"'A08G63#'!2`'!3(G82,'@!4@)\$2-
M+`A,B>!(BTPD<$G![`)(P>`>3`G@3(GN2#'"28V,")EY@EI(P>X;3"':08G$
M3#'R2`'*3(GI2,'A!4@)\4R)WDG!ZP)$C0012,'F'DB+5"1X3`G>2#'P3(G!
M08GS3"'H28V4%IEY@EI(P>D;3#'@2`'03(G"2,'B!4@)RDR)Z4G![0)$C30"
M2,'A'DB+E"2`````3`GI2(GP2#'(3(GV08G-3"'`28V4%)EY@EI(P>X;3#'8
M2`'03(GR2,'B!4@)\D2-)`),B<)(BX0DB````$G!Z`)(P>(>3`G"3(GF2#'1
M28V$`YEY@EI(P>X;3"'Q08G03#'I2`'!3(G@2,'@!4@)\$B+M"20````1(T<
M"$R)\$G![@)(P>`>3`GP28VT-9EY@EI-B=U(,<))P>T;B<%,(>),,<)(`?),
MB=Y(P>8%3`GNB?9(`?),B>9)P>P"2,'F'D&)U4P)YDR+I"28````2#'P3"'8
M3XV$()EY@EI(,<A-B>Q)P>P;3`'`38GH2<'@!4T)X$6)P$P!P$V)V$G!ZP))
MP>`>08G$30G828GSB?9-,<-(`[0DJ````$0QVDR+G"2@````2HV,&:'KV6Y-
MB>-)P>L;2`'13(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-B<5%
MB<!),=5,`X0DL````$0QZ$V)W4B-M`:AZ]EN3(G82<'M&TC!X`5,">B)P$@!
M\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1$,>%-B>Q(`Y0DN````$V-A`BA
MZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GSB?9)
M,<M(`[0DP````$0QV$V)XTB-E`*AZ]EN3(G@2<'K&TC!X`5,"=B)P$@!PDR)
MZ$G![0)(P>`>08G33`GH28G-B<E),<5(`XPDR````$4QZ$V)W4Z-A`:AZ]EN
M3(G>2<'M&TC!Y@5,">Z)]DP!QDV)X$G![`))P>`>08GU30G@28G$B<!-,<1$
M,>)-B>Q(C8P1H>O9;DR)ZDC!X@5)P>P;2`.$)-````!,">*)TD@!T4R)VDG!
MZP)(P>(>08G,3`G:38G#18G`23'33`.$)-@```!$,=Y-B>-(C;0PH>O9;DR)
MX$G!ZQM(P>`%3`G8B<!(`?!,B>Y)P>T"2,'F'D&)PTP)[DF)U8G223'U2`.4
M).````!$,>E-B=U-C80(H>O9;DR)V4G![1M(P>$%3`GIB<E)`<A,B>%)P>P"
M2,'A'D6)Q4P)X4F)](GV23',1#'@38GL2(V4`J'KV6Y,B>A)P>P;2,'@!4P)
MX(G`2`'"3(G82`.T).@```!)P>L"2,'@'D&)U$P)V$F)RXG)23'#2`.,)/``
M``!%,=A-B>-.C80&H>O9;DR)YDG!ZQM(P>8%3`G>B?9,`<9-B>A)P>T"2<'@
M'D&)\TT)Z$F)Q8G`33'%2`.$)/@```!$,>I-B=U(C8P1H>O9;DR)VDG![1M(
MP>(%3`GJB=)(`=%,B>))P>P"2,'B'D&)S4P)XDV)Q$6)P$DQU$0QYDV)[$B-
MM#"AZ]EN3(GH2<'L&TC!X`5,">")P$@!\$R)WDC!YAY)P>L"3`.$)``!``!,
M"=Y)B=-!B<1),?.)TD@#E"0(`0``1#'938GC38V$"*'KV6Y,B>%)P>L;2,'A
M!4P)V8G)20'(3(GI2<'M`DC!X1Y%B<-,">E)B?6)]DDQS4@#M"00`0``1#'H
M38G=2(V4`J'KV6Y,B=A)P>T;2,'@!4P)Z(G`2`'"3(G@2<'L`DC!X!Y!B=5,
M">!)B<R)R4DQQ$4QX$V)[$Z-A`:AZ]EN3(GN2<'L&TC!Y@5,">:)]DP!QDV)
MV$G!ZP))P>`>08GT30G82`.,)!@!``!)B<--,<.)P$@#A"0@`0``1#':38GC
M2<'K&TB-C!&AZ]EN3(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-
MB<5%B<!),=5,`X0D*`$``$0Q[DV)W4B-M#"AZ]EN3(G82<'M&TC!X`5,">B)
MP$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1(`Y0D,`$``$0QX4V)[$V-
MA`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GS
MB?9),<M$,=A-B>-(`[0D.`$``$B-E`*AZ]EN3(G@2<'K&TC!X`5,"=A$C1P0
M3(GH2<'M`DC!X!Y,">A)B<V)R4DQQ8G"13'H38G=3HV$!J'KV6Y,B=Y)P>T;
M2,'F!4P)[DR+K"1``0``1HTT!DV)X$G![`))P>`>30G@3`G`1(G&28G$2(G0
M2"'P32'<20G$N-R\&X])`<5,`>E-B?5)`<Q,B?%)P>T;2,'A!4P)Z4F)]4$!
MS$R)V4G!ZP)(P>$>3`G908G+20G(32'P32'=30GH3(NL)$@!``!)`<5,`>I-
MB>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B'DP)\DV)WD&)T$@)
MT4TAQDPAX4P)\4R+M"10`0``20'&3`'V38GN2`'Q3(GN2<'N&TC!Y@5,"?9$
MC30.3(GF2<'L`DC!YAY,">9-B<2)\4@)\DDAS$PAZDP)XDR+I"18`0``20'$
M30'C38GT3`':38GS2<'C!4G![!M-">-%C20338GK2<'M`DG!XQY-">M)B<U$
MB=I,"=Y)(=5,(?9,">Y,BZPD8`$``$D!Q4T!Z$V)Y4P!QDV)X$G![1M)P>`%
M30GH18TL,$V)\$G![@))P>`>30GP28G61(G&30G#22'V32'C30GS3(NT)&@!
M``!)`<9,`?%-B>Y)`<M,B>E)P>X;2,'A!4P)\4:--!E,B>%)P>P"2,'A'DP)
MX4F)]$&)RTD)R$TAZ$TAW$T)X$R+I"1P`0``20'$3`'B38GT20'03(GR2<'L
M&TC!X@5,">)&C20"3(GJ2<'M`DC!XAY,">I-B=U!B=!("=%-(<5,(?%,">E,
MBZPD>`$``$D!Q4P![DV)Y4@!\4R)YDG![1M(P>8%3`GN1(TL#DR)]DG![@)(
MP>8>3`GV38G&B?%("?))(<Y,(>),"?),B[0D@`$``$D!QDT!\TV)[DP!VDV)
MZTG!XP5)P>X;30GS18TT$TV)XTG![`))P>,>30GC28G,1(G:3`G>22'43"'N
M3`GF3(ND)(@!``!)`<1-`>!-B?1,`<9-B?!)P>P;2<'@!4T)X$6-)#!-B>A)
MP>T"2<'@'DT)Z$F)U42)QDT)PTDA]4TA\TT)ZTR+K"20`0``20'%3`'I38GE
M20'+3(GA2<'M&TC!X05,">E&C2P93(GQ2<'N`DC!X1Y,"?%)B?9)"<A!B<M-
M(=Y-(>!-"?!,B[0DF`$``$D!QDP!\DV)[DD!T$R)ZDG![AM(P>(%3`GR1HTT
M`DR)XDG![`)(P>(>3`GB38G<08G02`G132'$3"'I3`GA3(ND)*`!``!)`<1,
M`>9-B?1(`?%,B?9)P>P;2,'F!4P)YD2-)`Y,B>Y)P>T"2,'F'DP)[DV)Q8GQ
M2`GR22'-3"'R3`GJ3(NL)*@!``!)`<5-`>M-B>5,`=I-B>-)P>T;2<'C!4T)
MZT6-+!--B?-)P>X"2<'C'DT)\TF)SD2)VDP)WDDAUDPAYDP)]DR+M"2P`0``
M20'&30'P38GN3`'&38GH2<'N&TG!X`5-"?!%C30P38G@2<'L`DG!X!Y-">!)
MB=1$B<9-"<-)(?1-(>M-">-,BZ0DN`$``$D!Q$P!X4V)]$D!RTR)\4G![!M(
MP>$%3`GA1HTD&4R)Z4G![0)(P>$>3`GI28GU08G+20G(32'P32'=30GH3(NL
M),`!``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B
M'DV)V$P)\D&)UD@)T4TA\$PAX4P)P4R+A"3(`0``20'`3`'&38GH2`'Q3(GN
M2<'H&TC!Y@5,"<9$C00.3(GF2<'L`DC!YAY,B?%,">9!B?1("?),(>%,(>I(
M"<I(BXPDT`$``$@!P4D!RTR)P4@#A"38`0``3`':38G#2,'A!4G!ZQM,"=F)
MR4P!\$@!RDR)Z4G![0)(P>$>08G33`GI38GE08G/2`G.32']3"'&3`GN38G=
M2`'P3(G>2<'M&TC!Y@5,">Z)]D@!\$R)QDG!Z`)(P>8>08G%20GPOM;!8LI,
M,<$QRDB+C"3@`0``2`'Q20',3(GI3`'B38GL2,'A!4G![!M,">&)R4@!RDR)
MV4C!X1Y)P>L"08G420G+3(G!38GF3#'92<'N&T6)P#'(2(N,).@!``!(`?%)
M`<]*C0PX3(G@2,'@!4P)\(G`3(TT`4R)Z$G![0)(P>`>3(G918G;20G%2(N$
M)/`!``!%B?=,,>DQRDR)^4@!\$C!Z1M,`<!(`<),B?A(P>`%2`G(2(N,)/@!
M``")P$@!PDR)X$G![`)(P>`>2`'Q08G03`G@3`'938GK23'#38G$18GM13'>
M2<'L&TZ-'#%,B<%(P>$%3`GAB<E)`<M,B?E)P>\"2,'A'D6)W$D)STB+C"0`
M`@``2`'Q3`'I28G%B<!-,?U$,>I,C2P13(GB3(GA2,'I&TC!X@5("<I,B<%)
MP>@"B=)(P>$>20'52(N4)`@"``!,"<%-B?A%B>Y%B?]),<A(`?)%,<-(`=!,
MB?).C0083(GP2,'J&TC!X`5("=!(B<J)R8G`20'`3(G@2<'L`DC!X!Y%B<-)
M"<1(BX0D$`(``$PQXD$QU4R)VD@!\$P!^$D!Q4R)V$C!X`5(P>H;2`G03(GR
M2<'N`HG`2,'B'DD!Q4B+A"08`@``3`GR18GO2`'P2`'(3(GA18GD2#'103'(
M3(GY20'`3(GX2,'I&TC!X`5("<B)P$D!P$R)V$G!ZP)(P>`>18G&20G#2(N$
M)"`"``!,B?%(P>D;2`'P3`'@28G4B=)-,=Q%,>5.C20H3(GP2,'@!4@)R$B+
MC"0H`@``B<!)`<1,B?A)P>\"2`'Q2,'@'D6)Y4P)^$@!RDR)V4@QP46)VT$Q
MR$R)Z4D!T$R)ZDC!Z1M(P>(%2`G*B=))`=!,B?))P>X"2,'B'D6)QTD)UDB+
ME"0P`@``3(GY2,'I&T@!\DP!VDF)PXG`33'S13'<3HT<(DR)^DC!X@5("<I,
MB>E)P>T"B=)(P>$>20'32(N4)#@"``!,">E%B=Q(`?)(`=!,B?)%B?9(,<I!
M,=!,B>))`<!,B>!(P>H;2,'@!4@)T$B)RHG)B<!)`<!,B?A)P>\"2,'@'D6)
MQ4D)QTB+A"1``@``2`'P3#'Z3`'P03'33(GJ20'#3(GH2,'J&TC!X`5("=!,
MB>))P>P"B<!(P>(>20'#2(N$)$@"``!,">)%B=Y)B=1(`?!(`<A,B?E%B?](
M,=&)TD$QR$J-#`!,B?!-B?!)P>@;2,'@!4P)P(G`2`'!3(GH2<'M`DC!X!Y!
MB<A)"<5(BX0D4`(``$TQ[$4QXTV)Q$@!\$G![!M,`?A)`<-,B<!(P>`%3`G@
MB<!)`<-,B?!(P>`>2<'N`D6)W$P)\$R+M"18`@``20'V20'63(GJ18GM2#'"
M,=%)C10.3(GA38GF2<'N&TC!X05,"?&)R4@!RDR)P4G!Z`)(P>$>08G620G(
M2(N,)&`"``!(`?%,`>E)B<6)P$TQQ44QZTV)]4D!RTR)\4G![1M(P>$%3`GI
MB<E)`<M,B>%)P>P"2,'A'D6)W4D)S$B+C"1H`@``2`'Q2`'(3(G!18G`3#'A
M,<I(C0P03(GH3(GJ2,'J&TC!X`5("=!,B?))P>X"2,'B'HG`20G62(N4)'`"
M``!(`<&)R$@!\DP!PDV)X$TQ\$4QPTF)P$P!VDF)PTG!X`5)P>L;30G828G#
M2,'H`DG!XQY!`=!,B>I)"<-(BX0D>`(``$C!XAY)P>T"00';20G51(GB3(E?
M$$@!\$0![4@!PDR)\$B);QA,,>@QP4B-!`I,B<),B<%(P>(%2,'I&T4!R$@)
MRDR)1P@!T$$!PD0#=R!(BX0DB`(``&1(,P0E*````$R)%TR)=R!U$DB!Q)@"
M``!;74%<05U!7D%?P^CBX___9I!!5T%6055!5%532(/L"$B%_P^$L0```$R+
M/8IX(`!-A?\/A*$````/M@>$P'0$/#UU7D4QY$F+'TB%VW0Y28GU28G^36/D
M3(G]#Q^``````$R)XDR)]DB)W^C"XO__A<!U!T*`/",]=$=(@\4(2(M=`$B%
MVW7:2(/$"$B)V%M=05Q!74%>05_##Q^$``````!)B?Q)@\0!00^V!"2$P'0$
M/#UU[T$I_.N,#Q^``````$PI_4J-7",!2,']`T&);0#KM&8/'T0``#';ZZH/
M'T``55-(B?U(@^P89$B+!"4H````2(E$)`@QP$B-7"0$9I`QP$B)WDB)[^@#
M____2(7`=#9(8U0D!$B+!9IW(`!(C0302(M0"$B%TDB)$'329I!(@\`(2(M0
M"$B%TDB)$'7PZ[YF#Q]$``!(BT0D"&1(,P0E*````'4'2(/$&%M=P^B,XO__
M9I!F+@\?A```````05=!5D%505154TB)\TB)_4B#["AD2(L$)2@```!(B40D
M&#'`,<"`/CT/E,!(`<-(B=_H.>+__TB-="0428G$2(GO,<#H5_[__TB%P`^$
M#@$``$B)QTF)Q>@3XO__3#G@#X/B````3&-T)!1)P>8##[9%`(3`#X2M`0``
M/#T/A*4!``!(B>CK#0\?A```````@/H]=`M(@\`!#[80A-)U\$@IZ$B83`,U
MG'8@`$J-?"`"Z`KC__](A<!)B08/A'L!``!(8U0D%$B+!7IV(`!(C4T!2(L4
MT`^V10`\/8@"=":$P'40ZR!F+@\?A```````/#UT$DB#P0$/MD'_2(/"`83`
MB`)UZL8"/3'`#Q]$```/M@P#B$P"`4B#P`&$R77P,<!(BW0D&&1(,S0E*```
M``^%$0$``$B#Q"A;74%<05U!7D%?PP\?`$B#PP$/MD/_28/%`83`08A%_W7L
MZ\)FD$R+/>%U(`!)@S\`#X2_````3(GX,=+K"P\?A```````1(GJ2(/`"$2-
M:@%(@S@`=>^-<@-(8_9(P>8#BP7?A2``A<!U6TB)]\<%SH4@``$```#H">+_
M_TB%P`^$?0```$UCQ4R)_DB)QTZ--,4`````3(E$)`A,B?+HDN+__TR+1"0(
M2(G!2(D%6W4@`$K'1,$(`````$2);"04Z6_^__],B?_H2.+__TB%P$B)P4B)
M!3-U(`!T)DUCQ4Z--,4`````Z\D/'T``,<#I=O[__Y"^$````$4Q[>E>____
MN/_____IV_[__^@TX/__#Q]``$%6055!5%532('LH````&1(BP0E*````$B)
MA"28````,<!(A?]T"(`_`$B)^W4Q2(N$))@```!D2#,$)2@````/A2X!``!(
M@<2@````6UU!7$%=05[#9BX/'X0``````.AKW___2(7`28G$28GE=+],B>?H
MN.'__TB%P$B)Q0^$U`````^V51.X+@```(G!*=$/A:$````/ME44A=)TT2G0
M=08/MD45]]B%P'3##Q\`2(/%$TB)W^ADW___2(GO28G&Z%G?__]!C7P&`DAC
M_^B<X/__2(T-:1L``$F)QDB)QTF)Z4F)V$C'PO____^^`0```#'`Z.;A__^_
M`0```$R)ZDR)]NBVWO__@_C_3(GW=!"+1"08)0#P```]`$```'1+Z#G>__],
MB??H$=[__^D\____#Q]``(7)#X5P____3(GGZ.C@__](A<!(B<4/A3#___\/
M'T``3(GGZ%#?__](B=_HJ-[__^G"_O__Z([^___KL^BWWO__#Q^``````%-(
MB?N+/49S(`#HT=___TB-D``"``!(B=Z_`0```.CMX/__A<!T"3'`6\,/'T0`
M`(L]&G,@`.BEW___BX`8`@``)0#P```]`$```'0=BSW]<B``Z(C?__^+@!@"
M```E`/```#T`H```=;U(B=^^`@```.A9X/__A<`/E,`/ML!;PP\?1```9BX/
M'X0``````$%6055)B?9!5%5)B?Q32(T])1H``+K_#P``2('L$!```$B)XTB)
MWF1(BP0E*````$B)A"0($```,<#H0=W__X7`#XZ)````C5#_1(LM;W(@`$AC
MZH`\+`!T5DACZ$B)ZKXO````2(G?Z'/>__](A<!T1D2)[^C6WO__2(GI2(G:
M3(GF2(G'Z-7?__](BX0D"!```&1(,P0E*````'4[2('$$!```%M=05Q!74%>
MPV:0A=)UJ0\?0`!$B>_HD-[__TR)\DR)YDB)Q^B2W?__Z[M$BRWI<2``Z]_H
M0MW__V:02(/L"(L]UG$@`.AAWO__2(L5:G$@`$B-#3,;``!(C35%&0``2(G'
M2(/$".F`WO__2(/L"(L]IG$@`.@QWO__2(G'Z+G___^+/9-Q(`#H'M[__TR-
M!:<:``!(C17P$P``2(TU'AD``$4QR4B)QTB#Q`A,B<'IA][__P\?@`````!5
M4TB!["@@``!D2(L$)2@```!(B80D&"```#'`2(GC2(VL)!`0``#H%-S__TR-
M#;(8``!(C0W@&```08G`N@$0``"^`0```$B)WS'`Z!_?__^Z`!```$B)[DB)
MW^B_V___A<!X4XUX`4B)PTAC_^B-W?__2(7`2(G!=!A(8]M(B>Y(B<=(B=KH
M1-W__TB)P<8$&`!(BY0D&"```&1(,Q0E*````$B)R'432('$*"```%M=PP\?
M1```,<GKU^C_V___#Q]$``!F+@\?A```````Z2O___^09BX/'X0``````$%7
M059!54%428GT55-(B?M(C3TQ&```2('L*!```&1(BP0E*````$B)A"08$```
M,<!(C70D#.C%]___OB\```!(B=](B<7HM=O__TB%P'1`2(T]^A<``$B)WC'`
MZ/_X__](B=A(BXPD&!```&1(,PPE*`````^%F@$``$B!Q"@0``!;74%<05U!
M7D%?PP\?`$B)W^@XV___2(TUOQ<``$R)YT&)Q>AFW?__2(7`28G'=)Y!@\4!
M08`_`$R-9"003(TUFA<```^$X@````\?0`!(A>UT$TR)_DB)[^C@V___A<`/
MA*(```!,B?_HX-K__XG"2)A!@'P'_R]U%P\?0`"#Z@%(8\)!@'P'_R]!Q@0'
M`'3M1`'J@?K_#P``#X\N____2(/L"$B-#2D8``!-B?%338GXN@`0``"^`0``
M`$R)YS'`Z$C=__^+/3)O(`#HO=O__TB-D``"``!,B>:_`0```.@)VO__A<!:
M674=BST-;R``Z)C;__^+@!@"```E`/```#T`@```=%Y(C37-%@``,?_H>-S_
M_TB%P$F)QP^$K/[__T&`/P`/A2+___](A>UT'4B-/8P6``"Y`@```$B)[O.F
M=,1F+@\?A```````3(T];Q8``+H!````Z3+___\/'X``````O@$```!,B>?H
M"]S__X7`=9%(C3U1%@``3(GFZ%CW__],B>?H<-K__^E/_O__Z,;9__]F#Q]$
M```/MA=(B?B$TG0>9@\?1```2(/'`8#Z+P^V%T@/1,>$TG7N\\,/'T``\\-F
M#Q]$``!54TB#[`A(A?]T-0^V+TB)^T"$[70JZ&79__](C50#_T@YTW(4ZT]F
M#Q^$``````!(@^H!2#G3=$>`.B]T\NLMOP(```#HAMK__TB%P`^$E0```+HN
M````9HD02(/$"%M=PV8/'T0``(`Z+W0X2(/J`4@YTW+R2#G3=2H/'T0``$"`
M_2]TNDB#Q`A(C3U_%0``6UWIF-G__P\?A```````@#HO=0E(@^H!2#G3<O)(
M*=I(C4("2#T`$```=RM(C3W,;2``2(G>2(/"`;D`$```Z%O:__](@\0(2(T%
ML&T@`%M=PP\?1```2(/$"#'`6UW##Q]$``!F+@\?A```````4TB-/0H5``!(
M@^Q`9$B+!"4H````2(E$)#@QP`^W!746``!(C5PD#/,/;P5(%@``#RE$)!!F
MB40D,#'`\P]O!406```/*40D(.@R]?__2(T]QA0``#'`Z"3U__](C3W`%```
M,<#H%O7__TB-/;L4```QP.@(]?__2(T]M!0``#'`Z/KT__](C3VV%```,<#H
M[/3__TB-/5T4```QP.C>]/__2(T]IA0``#'`Z-#T__](C3VB%```,<#HPO3_
M_TB-/9X4```QP.BT]/__2(T]+A0``#'`Z*;T__](C3V,%```,<!(B=[HQ?/_
M_TB%P'012(T]8A0``$B)QC'`Z`_U__](C3UV%```,<!(B=[HGO/__TB%P'01
M2(T]<A0``$B)QC'`Z.CT__](C3UL%```,<!(B=[H=_/__TB%P'1"2(T]LQ,`
M`$B)QC'`Z,'T__](C35Q%```2(T]UA,``#'`Z*ST__](BT0D.&1(,P0E*```
M`'5B2(/$0%O#9@\?1```2(T])!0``#'`2(G>Z!_S__](A<!U*DB-="0A2(T]
M&A0``+D*````\Z9UI$B-="0K2(T]F!,``#'`Z%+T___KCTB-/8@3``!(B<8Q
MP.@_]/__Z7G____HM=;__P\?1```2(/L&&1(BP0E*````$B)1"0(,<"+!29K
M(`"#^/]T&4B+?"0(9$@S/"4H````=4!(@\08PP\?0`!(C70D!$B-/2L3```Q
MP.B%\O__2(G",<!(A=)T$@^V$H#Z,`^5P3'`A-(/E<`AR(D%TVH@`.NPZ#S6
M__]FD&8N#Q^$``````!(@^P(Z#?6__^)Q^C@U?__2(7`=`M(BP!(@\0(PP\?
M`#'`Z_1FD&8N#Q^$``````!!5%5(B?U32(T]*Q,``$B#[!!D2(L$)2@```!(
MB40D"#'`2(UT)`3H]/'__TB%P$B)[G1\@#@`2(G#='1(B<?H7-C__TB%P'5U
M2(GOZ)_5__](B=])B<3HE-7__TF-?`0"Z-K6__](@^P(3(T-#1(``$B-#?X2
M``!32,?"_____TB)QTF)Q$F)Z+X!````,<#H&]C__TB-/9T2``!,B>8QP.C:
M\O__6%KK%&8/'T0``$B-/8(2```QP.C"\O__2(M$)`AD2#,$)2@```!U"4B#
MQ!!;74%<P^@DU?__#Q]``$%7059!54%428G]55-(C3UT$0``2('LB($``&1(
MBP0E*````$B)A"1X@0``,<!(C05`$@``3(UD)"Q(QT0D0`````!(QX0DF```
M``````!(QT0D8`````!(B40D,$B-!2(1``!,B>9(B40D.$B-!:T1``!(B40D
M<$B-!9H1``!(B40D>$B-!>\1``!(B80D@````$B-!9P1``!(B80DB````$B-
M!=D1``!(B80DD````$B-!;$1``!(B40D4$B-!<(1``!(B40D6#'`Z'#P__](
MA<!T"8`X``^%0@0``#'`Z`O^__](A<!(B<,/A$\$``!(B=_H%]3__TB-?``!
MZ%W5__^`.P!)B<9T-TR-/7T1``!,B?4/'P!$#[8#2(GO,<!,B?E(Q\+_____
MO@$```!(@\,!2(/%`NB3UO__@#L`==9(C5PD<$B-/=(0``#K$$B#PPA(BSM(
MA?\/A'`!```QP$R)YNC6[___2(7`2(G%=-Z`.`!TV4B)Q^CQ]/__A<!TS4B)
M[^@UU/__2(7`28G'#X0Y`0``9@\?A```````3(G_Z&C3__],B?&+,4B#P02-
MEO_^_O[WUB'R@>*`@("`=.B)UL'N$/?"@(````]$UDB-<0)(#T3.B=9``-9(
M@]D#3"GQC9P(!`0``$ACVTB)W^AIU/__2(G%2(T%G!```$%63(T-E@\``$B-
M#8,0``!-B?A02,?"_____[X!````2(GO,<#HI=7__[[``0``2(GOZ#C2__^#
M^/]!6$%9=1+H^M'__T2+"$&#^1$/A=,(``"+/6=G(`#H\M/__TB-D``"``!(
MB>Z_`0```.@.U?__A<!!B<</A+,```!)BTT`2(L]>&<@`$B-%?$0``!)B>B^
M`0```#'`,=OH$-7__TB+C"1X@0``9$@S#"4H````2(G8#X5E"0``2('$B($`
M`%M=05Q!74%>05_##Q]``#'M9@\?1```2&/%2(M<Q#!(A=MT.X`[`'0V2(G?
M@\4!Z'OS__^%P'3?2(G?Z+_2__](A<!)B<</A9/^__](8\5(BUS$,$B%VW7+
M9@\?1```13'_Z7C^__\/'X0``````(L]BF8@`.@5T___BX`8`@``)0#P```]
M`$````^%+/___XL]:68@`.CTTO__1(NP'`(``.C(T?__03G&#X4,____BSU)
M9B``Z-32__^+@!@"```E_P$``#W``0``#X7K_O__2(G?Z,;2__](C3W##@``
M2(G#3(GF,<#HDNW__TB%P`^$^0$``$B)Q^@!TO__28M]`$B)QNAU]?__2(7`
M28G$#X39`0``3(GGZ#'1__^#^`-^/$ACT$B-/;0.``"Y!0```$F-=!3\\Z9U
M)(/X!`^$FP8``(/H!$B808!\!/\O#X2*!@``9BX/'X0``````#'`Z$GZ__^%
MP'45,?9,B>?HR]+__X7`08G&#X6``0``2(TU$`X``$B-/9$-``!,C26+#@``
M,<!,C2U"#0``Z#WN___H.-#__T%43(T-+PT``%!(C0U"#@``2,?"_____TF)
MZ+X!````2(G?,<#H/M/__UA:ZTUF+@\?A```````Z)O/__^#.!%U2^CQS___
M08/'`4B#[`A(C0T+#@``051!5TV)Z5!)B>A(Q\+_____O@$```!(B=\QP.CQ
MTO__2(/$(+[``0``2(G?Z(#/__^#^/]TJTB)[^@SS___2(T]A`P``$B)WC'`
MZ)+M__](B=_H"OK__^F%_?__#Q]$``!(B<=(B00DZ/3Y__](BP0D2(G'Z(C0
M__](B</I8/W__TB-/2(-```Q[4B%_W0F9I`QP$R)YH/%`>CCZ___2(7`=`6`
M.`!U*4ACQ4B+?,102(7_==R_#0```$B-'>X,``#HV]#__TF)QNE^^___#Q\`
M2(G'Z"C0__](A<!(B<,/A4W[___KP68N#Q^$``````!-BV4`Z1[^__\/'X``
M````N@(```!(Q\;N____B<?HS='__TB-A"1P`0``N@8```!$B?=(B<9(B00D
MZ`'0__^`O"1P`0```'4.@+PD<0$``$,/A(D%```QTC'V1(GWZ(W1__^XB:O-
M[TR-K"2@````2,>$)*`````!(T5G2(F$)*@```!(+8O.$E=(QX0DN````'94
M,A!(B80DL````$@%\@08*TC'A"3(`````````$B)A"3`````28U%.$C'A"30
M`````````,>$)!@!````````2(E$)`@/'X0``````$B+-"2Z`(```$2)]^A/
MS___A<!)B<1!B<`/CG$!``!(B[PDR````$ECQ$B+E"30````C33'2#G^2(FT
M),@```!(@](`2,'H'4@!T$B)A"30````2&.$)!@!``"%P`^$'0$``$B+3"0(
M0;A`````2(LT)$$IP$4YQ$4/3L1(C3P!26/028G72(E4)!#H$,___XN$)!@!
M``!$`?B#^$")A"08`0``#X56____18G@3(GO12GX3(M\)!!,`SPD1(E$)!SH
MVM/__T2+1"0<#Q]$``!!@_@_?GE!C4#`B40D','H!D&)Q(E$)!!)@\0!2<'D
M!DT!_`\?1```\T$/;P=,B>])@\=`#Q&$)-@```#S00]O1]`/$80DZ````/-!
M#V]'X`\1A"3X````\T$/;T?P#Q&$)`@!``#H9=/__TTY_'6XBT0D$$2+1"0<
MP>`&02G`2(M\)`A)8]"Y2````$R)_D2)1"00Z"?.__]$BT0D$$2)A"08`0``
MZ87^__\/'T0``$R+/"3I1____P\?@`````!$B??H:,W__TR+I"3(````3(NT
M)-````!,B>!(P>@#@^`_C5`!2)C&A`38````@(/Z.`^/@P(``+@X````,?8I
MT$ACTH/X"$F-5!4X#X/<`@``J`0/A88#``"%P'0+J`+&`@`/A8H#``!,B?!,
MB>]$B+0D$P$``$C!Z!A$B*0D%P$``$R-K"1``0``B(0D$`$``$R)\$C!Z!"(
MA"01`0``3(GP3(TUQ0D``$C!Z`B(A"02`0``3(G@2,'H&(B$)!0!``!,B>!(
MP>@0B(0D%0$``$R)X$4QY$C!Z`B(A"06`0``Z"G2__](BX0DH````$B)PHB$
M)",!``!(P>H81`^VPHB4)"`!``!(B<)(P>H0B)0D(0$``$B)PDB+A"2H````
M2,'J"(B4)"(!``!(B<*(A"0G`0``2,'J&(B4)"0!``!(B<)(P>H0B)0D)0$`
M`$B)PDB+A"2P````2,'J"(B4)"8!``!(B<*(A"0K`0``2,'J&(B4)"@!``!(
MB<)(P>H0B)0D*0$``$B)PDB+A"2X````2,'J"(B4)"H!``!(B<*(A"0O`0``
M2,'J&(B4)"P!``!(B<)(P>H0B)0D+0$``$B)PDB+A"3`````2,'J"(B4)"X!
M``!(B<*(A"0S`0``2,'J&(B4)#`!``!(B<)(P>H0B)0D,0$``$B)PDC!Z@B(
ME"0R`0``Z0P````/'P!&#[:$)"`!``!+C7QE`#'`3(GQ2,?"_____[X!````
M28/$`>AXS?__28/\%'722(T%>P@``,:$)&@!````4$%52(T--0@``$R-#2('
M``"^`0```$F)Z$C'PO____](B=\QP.@YS?__65[I5_K__V:038MM"$V%[0^$
M<_G__TR)[^A;RO__2(/X`P^&8?G__TF-=`7\2(T]W`<``+D%````\Z9-#T3E
MZ47Y__^X0````$ACRBG028U,#3AT#S'2B=:#P@$YPL8$,0!R\TR)[^@MT/__
M9@_OP`\1A"38````2<=%:`````!!#Q%%2$$/$458Z6/]__])BTT`2(L]SUX@
M`$B-%0@(``!)B>B^`0```#'`,=OH9\S__^E2]___B<%(QP(`````2,=$"O@`
M````2(U*"$B#X?A(*<H!T(/@^(/X"`^"$/W__X/@^#'2B=>#P@@YPDB)-#ER
M\^GY_/__@+PD<@$``$$/A6GZ__^`O"1S`0``0P^%6_K__X"\)'0!``!(#X5-
M^O__@+PD=0$``$4/A3_Z__^Z`@```$C'QL;___]$B??HQ,O__TR+/"2Z*0``
M`$2)]TR)_N@`RO__2(T%Z08``%!!5^EQ_O__D,<"`````,=$`OP`````Z7;\
M__\Q_V:)?`+^Z6K\___H_,C__V:09BX/'X0``````$%7059!54%455-(@^P8
MBSU\72``9$B+!"4H````2(E$)`@QP$R-;"0$Z/+)__^+/5Q=(`!(B</HY,G_
M_P^VD[@```!(C3U)!0``3(GNB)"Y````,<#HMN3__TB%P'0)@#@Q#X0(`P``
M,<#H\>___XL]&UT@`.BFR?__2(TU*08``+D+````N@$```!(B<?H3<G__TB%
MP`^$Q````(,]76T@``%(BT`01(LUXEP@`$R+8"@/CJ\````Q[;L!````ZSH/
M'X``````28MW$$B+!25M(`!(8]-(BSS0Z/'(__^%P(L5&6T@``^%"`(``(/#
M`8/%`3G3#XWZ`0``1(GWZ!W)__\QR4ACU4R)YDB)Q^CMR?__2(7`#X3,`0``
M3(LX1(LU:EP@`$&+1PPE``0@`#T`!```=))$B??HXLC__TR)_KD"````,=)(
MB<?H\,?__T2+-3E<(`!(B<;I;?___Y!$BS4I7"``1(GWZ+'(__](C34Y!0``
MN0,```"Z`0```$B)Q^A8R/__2(7`2(G#=#5(BT`0BSWV6R``2(LHZ'[(__](
MC14(!0``2(G'2(GNZ'S'__](BT,02(L8]D,.0`^%ZP$``(L]Q5L@`.A0R/__
M2(TU^`0``+D#````N@$```!(B<?H]\?__TB%P$B)PW0]2(T]:0,``#'`3(GN
MZ`[C__](A<!(B<4/A'(!``!(BT,0BSUX6R``2(L8Z`#(__](B>I(B<=(B=[H
M`L?__XL]7%L@`.CGQ___2(TU=@0``+H!````2(G'Z//'__^+/3U;(`!(B</H
MQ<?__TB-%6D$``!(B=Y(B<?HP\;__XL]'5L@`.BHQ___2(T]V0(``,:`N0``
M``!,B>XQP.B`XO__2(7`2(G#2(D%:VL@``^$G0```+[``0``2(G?Z)#%__^-
M4`&#^@%V"8/X$0^%#P$``$B+1"0(9$@S!"4H````#X7V````2(/$&%M=05Q!
M74%>05_##Q]``(L5$FL@`$2+-9M:(`"-0O\YZ`^%9_[__X/Z`0^.7O[__[L!
M````9I!$B?>#PP'H!<?__TR)YDB)Q^@ZQ?__.1W4:B``1(LU75H@`'_;Z2W^
M__]F#Q]$``!(BSVQ:B``Z(3P__](A<!(B<-(B06O:B``#X5$____2(T]0@0`
M`#'`Z./&__\/'P"`>`$`#X3U_/__Z>G\__^02(L%<6H@`(L]`UH@`$B+*$B+
M0Q!(BQCHA,;__TB)[DB)W^@IY___Z8+^__\/'T``BSW:62``Z&7&__](B=Y(
MB<?HNL;__^GZ_?__Z"#%__^)P4B+!1]J(`!(C3WP`P``2(G:2(LP,<#H8\;_
M_P\?`%532(G]2(/L".ABZ___#[802(G#A-)T&@\?A```````2(/``8#Z+P^V
M$$@/1-B$TG7N,<#H%^[__TB%[70=A<!T&8!]``!T$TB-/2X"``"Y!````$B)
MWO.F=`=(@\0(6UW#2(/$"$B)[UM=Z6#D__](C04162``2(7`=`Q(BPCI#,7_
M_P\?0``QR>D!Q?__D$%7059!B?]!54%43(TE/E0@`%5(C2T^5"``4TF)]DF)
MU4PIY4B#[`A(P?T#Z!_#__](A>UT(#';#Q^$``````!,B>I,B?9$B?]!_Q3<
M2(/#`4@YW77J2(/$"%M=05Q!74%>05_#D&8N#Q^$``````#SPP``2(/L"$B#
MQ`C#`````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0
M051(`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R
M>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S
M=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`4$%2.CI0
M86-K97(Z.E9%4E-)3TX`,2XP-#``+64`+2T``%]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@``````````!P97)L>'-I+F,`````````)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U
M;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T
M:6]N*0H```````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``
M````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U
M;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N
M("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D
M=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D
M=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD
M('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA
M;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@
M9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN
M:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#
M;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G
M.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H
M)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R
M;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D
M871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P
M96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D[
M"FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T
M(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D
M<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@
M,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*
M;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR
M96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@
M/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I
M.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O
M9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE
M<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@
M+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O
M9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L
M(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L
M:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U
M;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN
M86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<
M9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT
M*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(
M+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX
M?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT
M(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN
M86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL
M96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\
M7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@
M)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@
M,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*
M?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`
M7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL
M96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R![
M"FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT
M('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@
M;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE
M+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA
M;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS
M92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C
M?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D
M9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB
M:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG
M(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F
M:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R
M=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF
M="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@
M:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@
M("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM
M<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@
M<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R
M"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@
M+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q
M("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU
M;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD
M;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I
M=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]
M"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@
M97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@
M0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O
M<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D[
M"F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G
M(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY
M("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@
M/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T
M82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<
M-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R
M(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N
M;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,
M62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D
M871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]
M('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P
M;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES
M("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`]
M(&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?
M7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?
M(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@
M*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N
M9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@
M=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK
M(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E
M24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*
M;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@
M*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H
M)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]
M("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:
M+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I
M9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R
M968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R
M:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE
M(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K
M:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q
M*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N
M=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L
M("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E
M*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I
M"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M
M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA
M<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET
M=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT
M*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#
M,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]
M"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H
M95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@
M)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(
M02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$
M:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V
M86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V
M97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2![
M"B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92![
M"FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D
M92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD
M8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64[
M"GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L
M96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD
M9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U
M;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E
M<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*
M<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B
M)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B
M.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD
M<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D[
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E
M="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM
M96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D
M;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@
M)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO
M*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D
M97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]
M+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]
M/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP
M<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A
M="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG
M("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE
M>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D
M97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S
M($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M
M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\
M+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T
M95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N
M86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE
M.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D
M<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E
M7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR
M97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI
M;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E
M<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@
M>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I
M;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"![
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E
M86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII
M9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@
M/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I
M('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D
M14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U
M<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N
M9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D
M9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A
M9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@
M/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@
M?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D52
M4TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S
M:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA
M;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E
M;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X
M+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I
M9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[
M4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT
M96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@
M=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@
M)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@
M:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE
M*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]
M"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P
M<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP
M871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@
M/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE
M9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F
M5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H
M;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[
M7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@
M96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@
M05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ
M=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD
M7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%2
M7T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI
M('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D
M14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D
M<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,
M14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*
M?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*
M<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]
M"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@
M9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R
M8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E
M;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR
M97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!
M4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P
M96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D
M:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE
M.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*
M?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$[
M"E]?14Y$7U\*```````!&P,[[````!P```"@@___.`$``&"'__]@`0``<(?_
M_S@&``"@B?__"`$``+"*__]X`0``P*#__\@!``"0H?__%`(``""B__]``@``
M<*3__XP"``#PI?__T`(``("F___P`@``8*?__S0#``"0I___3`,``."G__]D
M`P``L*C__Y`#``#`J/__I`,``."J__\$!```$*O__Q@$```0K/__9`0``/"M
M__^(!```<*[__Z0$``"@KO__P`0``("O__\`!0``L+O__[@%``"@O___!`8`
M`!#`__]H!@``,,#__X`&``"@P/__R`8````````4``````````%Z4@`!>!`!
M&PP'")`!!Q`4````'````)"(__\K```````````````4``````````%Z4@`!
M>!`!&PP'")`!```D````'````&""___``P````X01@X82@\+=PB``#\:.RHS
M)"(`````%````$0```#XA?__"```````````````3````%P````PB?__#A8`
M``!"#A"/`D(.&(X#1@X@C01"#BB,!40.,(8&00XX@P='#M`%`^85"@XX00XP
M00XH0@X@0@X80@X00@X(00L```!(````K````/">___,`````$(.$(\"0@X8
MC@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)L"@XX1`XP00XH0@X@0@X80@X0
M0@X(20L`*````/@```!TG___A`````!!#A"&`D$.&(,#1PXP`G,*#AA!#A!!
M#@A!"P!(````)`$``-B?__],`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XP
MA@9!#CB#!TH.8`,F`0H..$$.,$$.*$(.($(.&$(.$$(."$0+0````'`!``#<
MH?__>0$```!"#A".`D(.&(T#0@X@C`1!#BB&!4$.,(,&1P[0`7X*#C!!#BA!
M#B!"#AA"#A!"#@A+"P`<````M`$``!BC__^!`````$$.$(,":0H."$8+`E`.
M"$````#4`0``B*/__]X`````0@X0C@)"#AB-`T4.((P$00XHA@5$#C"#!E,.
MP"`"A`H.,$$.*$$.($(.&$(.$$(."$,+%````!@"```DI/__,`````!$#A!G
M#@@`%````#`"```\I/__20````!$#A!]#@@`*````$@"``!TI/__P0````!!
M#A"&`D$.&(,#1P[`0`*G"@X800X000X(1@L0````=`(``!BE__\%````````
M`%P```"(`@``%*7__QH"````0@X0CP)"#AB.`T(.((T$0@XHC`5$#C"&!D$.
M.(,'40[@(`)D"@XX00XP00XH0@X@0@X80@X00@X(1`L"E@[H($L.\"!Y#N@@
M00[@(````!````#H`@``U*;__RH`````````2````/P"``#PIO__\0````!!
M#A"&`D$.&(,#1`X@`ED*#AA!#A!!#@A'"V(*#AA(#A!!#@A-"WD*#AA(#A!!
M#@A&"T0.&$,.$$$.""````!(`P``I*?__]L!````00X0@P)+#E`#;`$*#A!!
M#@A'"Q@```!L`P``8*G__W0`````1`X@;PH."$4+```8````B`,``,2I__\D
M`````$0.$%@*#@A$"P``/````*0#``#8J?__W`````!"#A",`D$.&(8#1`X@
M@P1+#C`"6`XX3PY`;@XX00XP:@H.($$.&$$.$$(."$$+`+0```#D`P``>*K_
M_R0,````0@X0CP)"#AB.`T(.((T$0@XHC`5$#C"&!D$..(,'3@[`@P(#Z`$.
MR(,"4@[0@P)H#LB#`D(.P(,"`H(*#CA!#C!!#BA"#B!"#AA"#A!"#@A%"P.:
M`0[(@P)(#M"#`F$.R(,"00[`@P)C#LB#`DD.T(,"0@[8@P)$#N"#`ET.P(,"
M`XL%#LB#`D(.T(,":`[(@P)!#L"#`@-?`0H.R(,"0@[0@P)&"P!(````G`0`
M`/"U___M`P```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.4`/+
M`@H..$$.,$$.*$(.($(.&$(.$$(."$4+,````.@$``"4N?__<`````!!#A"&
M`D$.&(,#1PX@`E8*#AA!#A!!#@A!"T0.&$0.$$$.""P````<!0``,('__RT"
M````00X0A@)!#AB#`T0.4`.]`0H.&$$.$$$."$$+`````!0```!,!0``H+G_
M_Q\``````````````$0```!D!0``J+G__V4`````0@X0CP)"#AB.`T4.((T$
M0@XHC`5(#C"&!D@..(,'30Y`<@XX00XP00XH0@X@0@X80@X00@X(`!````"L
M!0``T+G__P(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````@"$`
M``````!`(0````````````````````````````````````````$`````````
M`0`````````!`````````,L!`````````0````````#6`0````````$`````
M````X`$````````!`````````"\"`````````0````````!]`P````````P`
M````````8!H````````-`````````(17````````&0````````!@JR``````
M`!L`````````"``````````:`````````&BK(```````'``````````(````
M`````/7^_V\`````F`(````````%``````````@-````````!@````````"0
M`P````````H`````````[@0````````+`````````!@`````````%0``````
M``````````````,`````````R*T@```````"`````````(@%````````%```
M```````'`````````!<`````````V!0````````'`````````$`3````````
M"`````````"8`0````````D`````````&``````````>``````````@`````
M````^___;P`````!```(`````/[__V\`````P!(```````#___]O``````(`
M````````\/__;P````#V$0```````/G__V\`````!```````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(BK(```````````````````
M`````````)8:````````IAH```````"V&@```````,8:````````UAH`````
M``#F&@```````/8:````````!AL````````6&P```````"8;````````-AL`
M``````!&&P```````%8;````````9AL```````!V&P```````(8;````````
MEAL```````"F&P```````+8;````````QAL```````#6&P```````.8;````
M````]AL````````&'````````!8<````````)AP````````V'````````$8<
M````````5AP```````!F'````````'8<````````AAP```````"6'```````
M`*8<````````MAP```````#&'````````-8<````````YAP```````#V'```
M``````8=````````%AT````````F'0```````#8=````````1AT```````!6
M'0```````&8=````````=AT```````"&'0```````)8=````````IAT`````
M``"V'0```````,8=````````UAT```````#F'0```````/8=````````!AX`
M```````6'@```````"8>````````-AX`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````BP(```````_____P````"H6@```````$=#
M0SH@*$1E8FEA;B`W+C(N,"TQ,BD@-RXR+C$@,C`Q-S$P,C4`1T-#.B`H1&5B
M:6%N(#8N-"XP+30I(#8N-"XP(#(P,3<P.#(P```N<VAS=')T86(`+FEN=&5R
M<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N
M<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YP;'0N9V]T`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`
M+F9I;FE?87)R87D`+F1A=&$N<F5L+G)O`"YD>6YA;6EC`"YD871A`"YB<W,`
M+F-O;6UE;G0`````````````````````````````````````````````````
M````````````````````````````````````````"P````$````"````````
M`#@"````````.`(````````<`````````````````````0``````````````
M`````!,````'`````@````````!4`@```````%0"````````(```````````
M``````````0````````````````````A````!P````(`````````=`(`````
M``!T`@```````"0````````````````````$````````````````````-```
M`/;__V\"`````````)@"````````F`(```````#X``````````4`````````
M"````````````````````#X````+`````@````````"0`P```````)`#````
M````>`D````````&`````0````@`````````&`````````!&`````P````(`
M````````"`T````````(#0```````.X$```````````````````!````````
M````````````3@```/___V\"`````````/81````````]A$```````#*````
M``````4``````````@`````````"`````````%L```#^__]O`@````````#`
M$@```````,`2````````@``````````&`````@````@`````````````````
M``!J````!`````(`````````0!,```````!`$P```````)@!````````!0``
M```````(`````````!@`````````=`````0```!"`````````-@4````````
MV!0```````"(!0````````4````7````"``````````8`````````'X````!
M````!@````````!@&@```````&`:````````%P````````````````````0`
M``````````````````!Y`````0````8`````````@!H```````"`&@``````
M`,`#```````````````````0`````````!``````````A`````$````&````
M`````$`>````````0!X````````(````````````````````"``````````(
M`````````(T````!````!@````````!0'@```````%`>````````,CD`````
M`````````````!````````````````````"3`````0````8`````````A%<`
M``````"$5P````````D````````````````````$````````````````````
MF0````$````"`````````)!7````````D%<```````!0/P``````````````
M````"````````````````````*$````!`````@````````#@E@```````."6
M````````[`````````````````````0```````````````````"O`````0``
M``(`````````T)<```````#0EP```````/`%```````````````````(````
M````````````````N0````X````#`````````&"K(```````8*L````````(
M````````````````````"``````````(`````````,4````/`````P``````
M``!HJR```````&BK````````"`````````````````````@`````````"```
M``````#1`````0````,`````````<*L@``````!PJP```````!,`````````
M```````````0````````````````````W@````8````#`````````(BK(```
M````B*L```````!``@````````8`````````"``````````0`````````(@`
M```!`````P````````#(K2```````,BM````````,`(`````````````````
M``@`````````"`````````#G`````0````,``````````+`@````````L```
M`````"`````````````````````(````````````````````[0````@````#
M`````````""P(```````(+````````"($```````````````````(```````
M`````````````/(````!````,````````````````````""P````````2P``
M``````````````````$``````````0`````````!`````P``````````````
M``````````!KL````````/L````````````````````!````````````````
#````
